@@ -70,11 +70,16 @@ class KNSBackendFactory : public AbstractResourcesBackendFactory {
 #else
             QStringList locations = QStandardPaths::standardLocations(QStandardPaths::GenericConfigLocation);
 #endif
+            QSet<QString> files;
             for (const QString &path: locations) {
                 QDirIterator dirIt(path, {QStringLiteral("*.knsrc")}, QDir::Files);
                 for(; dirIt.hasNext(); ) {
                     dirIt.next();
 
+                    if (files.contains(dirIt.fileName()))
+                        continue;
+                    files << dirIt.fileName();
+
                     auto bk = new KNSBackend(parent, QStringLiteral("plasma"), dirIt.filePath());
                     if (bk->isValid())
                         ret += bk;
@@ -504,7 +509,7 @@ ResultsStream* KNSBackend::search(const AbstractResourcesBackend::Filters& filte
         }
 
         return stream;
-    } else if ((m_hasApplications && !filter.category) // If there is no category defined, we are searching in the root, and should include only application results
+    } else if ((!filter.category && !filter.search.isEmpty()) // Accept global searches
               // If there /is/ a category, make sure we actually are one of those requested before searching
            || (filter.category && kContains(m_categories, [&filter](const QString& cat) { return filter.category->matchesCategoryName(cat); }))) {
         auto r = new ResultsStream(QLatin1String("KNS-search-")+name());
@@ -549,7 +554,11 @@ ResultsStream * KNSBackend::findResourceByPackageName(const QUrl& search)
     if (search.scheme() != QLatin1String("kns") || search.host() != name())
         return voidStream();
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     const auto pathParts = search.path().split(QLatin1Char('/'), QString::SkipEmptyParts);
+#else
+    const auto pathParts = search.path().split(QLatin1Char('/'), Qt::SkipEmptyParts);
+#endif
     if (pathParts.size() != 2) {
         Q_EMIT passiveMessage(i18n("Wrong KNewStuff URI: %1", search.toString()));
         return voidStream();
@@ -562,7 +571,8 @@ ResultsStream * KNSBackend::findResourceByPackageName(const QUrl& search)
         m_responsePending = true;
         m_engine->fetchEntryById(entryid);
         m_onePage = false;
-        connect(m_engine, &KNSCore::Engine::signalError, stream, &ResultsStream::finish);
+
+        connect(m_engine, &KNSCore::Engine::signalErrorCode, stream, &ResultsStream::finish);
         connect(m_engine, &KNSCore::Engine::signalEntryDetailsLoaded, stream, [this, stream, entryid, providerid](const KNSCore::EntryInternal &entry) {
             if (entry.uniqueId() == entryid && providerid == QUrl(entry.providerId()).host()) {
                 Q_EMIT stream->resourcesFound({resourceForEntry(entry)});
